% calculation_eq32.m
%
% Compute a^4*g'(d_1) in equation (32), the bound on the derivative dh^3/dp 
% for Example 1.
%
% --
% Supplementary material to
%
% S. Trimpe, R. D'Andrea, "Event-Based State Estimation with Variance-Based 
% Triggering", Proc. of the 51st IEEE Conference on Decision and Control, 
% 2012.
%
% Copyright:
% Sebastian Trimpe
% ETH Zurich
% Institute for Dynamic Systems and Control (IDSC)
% strimpe(at)ethz.ch
% March 2012
%

% Revision history
% [March 12, Seb]   first version

clear;
clc;


%% Settings
% Symbolic variables
syms a c p d;       % d for \delta

% Parameter values
a_ = 1.2;
c_ = 1;
d_ = 3;

% Function g (eq. (24))
g = a^2*p +1 -a^2*c^2*p^2/(c^2*p+1);


%% Preliminaries
% 1st derivative
dg = simplify(diff(g,p));

% disp('dg/dp:');
% pretty(dg);
% disp(' ');

% positive solution to DARE (6)
solDARE = simplify(solve(g-p,p));
pbar = solDARE(1);      % Take positive solution -> \bar{p}.

% disp('\bar{p}:');
% pretty(pbar);
% disp(' ');


%% Calculation: bound on derivative
% Compute a^4 * g'(d_1) (symbolic), equation (32)
% d_1 = \bar{p} + \delta
bound = a^4*subs(dg,p,pbar+d); 

% Evaluate with parameter values
num_bound = subs(bound,[a c d],[a_ c_ d_]);

% Result:
disp('RESULT (equation (32)):');
disp('bound a^4*g''(d_1) (symbolic):');
pretty(bound);
disp(' ');
disp('bound a^4*g''(d_1) (numeric):');
disp(num_bound);
disp(' ');